@@ -1,4 +1,3 @@
-
 #' @title Select columns with evaluation metrics and model definitions
 #' @description
 #'  \Sexpr[results=rd, stage=render]{lifecycle::badge("maturing")}
@@ -19,7 +18,6 @@
 #' @param additional_includes Names of additional columns to select. (Character)
 select_metrics <- function(results, include_definitions = TRUE,
                            additional_includes = NULL) {
-
   # Check arguments ####
   assert_collection <- checkmate::makeAssertCollection()
   checkmate::assert_data_frame(
@@ -29,8 +27,10 @@ select_metrics <- function(results, include_definitions = TRUE,
     add = assert_collection
   )
   checkmate::assert_flag(x = include_definitions, add = assert_collection)
-  checkmate::assert_character(x = additional_includes, null.ok = TRUE,
-                              add = assert_collection)
+  checkmate::assert_character(
+    x = additional_includes, null.ok = TRUE,
+    add = assert_collection
+  )
   if (!is.null(additional_includes)) {
     checkmate::reportAssertions(assert_collection)
     checkmate::assert_names(
@@ -79,7 +79,7 @@ select_metrics <- function(results, include_definitions = TRUE,
   metric_cols <- add_additional_colnames(metric_cols, additional_includes)
   if (isTRUE(include_definitions)) {
     metric_cols <- add_additional_colnames(metric_cols, model_formula_cols)
-    if ("Fixed" %in% metric_cols){
+    if ("Fixed" %in% metric_cols) {
       metric_cols <- c("Fixed", metric_cols[metric_cols != "Fixed"])
     }
   }
