@@ -31,7 +31,6 @@ render_toc <- function(filename,
                        toc_header_name = "Table of Contents",
                        base_level = NULL,
                        toc_depth = 3) {
-
   x <- readLines(filename, warn = FALSE)
   x <- gsub("<a.*<img.*a>", "", x) # My addition, remove links with images in
   x <- paste(x, collapse = "\n")
@@ -78,6 +77,7 @@ render_toc <- function(filename,
     paste0(strrep(" ", level * 4), "- [", header_text, "](#", header_slug, ")")
   })
   x <- x[x != ""]
-  if (requireNamespace("knitr", quietly = TRUE))
+  if (requireNamespace("knitr", quietly = TRUE)) {
     knitr::asis_output(paste(x, collapse = "\n"))
+  }
 }
